==> open-xchange-documents-backend_7.8.4.orig.tar.bz2: open-xchange-documents-backend-7.8.4/com.openexchange.office.filter.ooxml/src/com/openexchange/office/filter/ooxml/drawingml/Picture.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.filter.ooxml.drawingml;

import org.docx4j.dml.CTBlipFillProperties;
import org.docx4j.dml.IPicture;
import org.docx4j.openpackaging.exceptions.InvalidFormatException;
import org.docx4j.openpackaging.exceptions.PartUnrecognisedException;
import org.docx4j.openpackaging.parts.Part;
import org.json.JSONException;
import org.json.JSONObject;

import com.openexchange.office.filter.api.FilterException;
import com.openexchange.office.filter.ooxml.OperationDocument;

public class Picture {

	public static void applyAttrsFromJSON(OperationDocument operationDocument, JSONObject attrs, Part part, IPicture pic, boolean rootComponent)
    	throws JSONException, InvalidFormatException, PartUnrecognisedException {

        DMLHelper.applyNonVisualDrawingProperties(pic, attrs.optJSONObject("drawing"));
        DMLHelper.applyNonVisualDrawingShapeProperties(pic, attrs.optJSONObject("drawing"));
	    DMLHelper.applyShapePropertiesFromJson(pic.getSpPr(), attrs, operationDocument, part, rootComponent);
	    DMLHelper.applyBlipFillPropertiesFromJson(pic.getBlipFill(true), operationDocument, part, attrs.optJSONObject("image"));
	}

    public static void createJSONAttrs(OperationDocument operationDocument, JSONObject attrs, Part part, IPicture pic, boolean rootComponent)
    	throws JSONException, FilterException {

        DMLHelper.createJsonFromNonVisualDrawingProperties(attrs, pic);
        DMLHelper.createJsonFromNonVisualDrawingShapeProperties(attrs, pic);
        DMLHelper.createJsonFromShapeProperties(attrs, pic.getSpPr(), operationDocument.getThemePart(true), pic.getStyle(), part, true, rootComponent);
        final CTBlipFillProperties blipFillProperties = pic.getBlipFill(false);
        if(blipFillProperties!=null) {
			final JSONObject imageAttrs = new JSONObject();
            DMLHelper.createJsonFromBlipFillProperties(part, imageAttrs, blipFillProperties);
            if(!imageAttrs.isEmpty()) {
            	attrs.put("image", imageAttrs);
            }
        }
    }
}

==> open-xchange-documents-backend_7.10.0.orig.tar.bz2: open-xchange-documents-backend-7.10.0/com.openexchange.office.filter.ooxml/src/com/openexchange/office/filter/ooxml/drawingml/Picture.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.filter.ooxml.drawingml;

import org.docx4j.dml.CTBlipFillProperties;
import org.docx4j.dml.IPicture;
import org.docx4j.openpackaging.exceptions.InvalidFormatException;
import org.docx4j.openpackaging.exceptions.PartUnrecognisedException;
import org.docx4j.openpackaging.parts.Part;
import org.json.JSONException;
import org.json.JSONObject;
import com.openexchange.office.filter.api.FilterException;
import com.openexchange.office.filter.api.OCKey;
import com.openexchange.office.filter.ooxml.OperationDocument;

public class Picture {

	public static void applyAttrsFromJSON(OperationDocument operationDocument, JSONObject attrs, Part part, IPicture pic, boolean rootComponent)
    	throws JSONException, InvalidFormatException, PartUnrecognisedException {

        DMLHelper.applyNonVisualDrawingProperties(pic, attrs.optJSONObject(OCKey.DRAWING.value()));
        DMLHelper.applyNonVisualDrawingShapeProperties(pic, attrs.optJSONObject(OCKey.DRAWING.value()));
	    DMLHelper.applyShapePropertiesFromJson(pic.getSpPr(), attrs, operationDocument, part, rootComponent);
	    DMLHelper.applyBlipFillPropertiesFromJson(pic.getBlipFill(true), operationDocument, part, attrs.optJSONObject(OCKey.IMAGE.value()));
	}

    public static void createJSONAttrs(OperationDocument operationDocument, JSONObject attrs, Part part, IPicture pic, boolean rootComponent)
    	throws JSONException, FilterException {

        DMLHelper.createJsonFromNonVisualDrawingProperties(attrs, pic);
        DMLHelper.createJsonFromNonVisualDrawingShapeProperties(attrs, pic);
        DMLHelper.createJsonFromShapeProperties(attrs, pic.getSpPr(), operationDocument.getThemePart(true), pic.getStyle(), part, true, rootComponent);
        final CTBlipFillProperties blipFillProperties = pic.getBlipFill(false);
        if(blipFillProperties!=null) {
			final JSONObject imageAttrs = new JSONObject();
            DMLHelper.createJsonFromBlipFillProperties(part, imageAttrs, blipFillProperties);
            if(!imageAttrs.isEmpty()) {
            	attrs.put(OCKey.IMAGE.value(), imageAttrs);
            }
        }
    }
}
